OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "\"config\" dizinine yazılamıyor!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Bu genellikle, web sunucusuna config dizinine yazma erişimi verilerek çözülebilir",
    "See %s" : "Bakınız: %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Bu genellikle, %sweb sunucusuna config dizinine yazma erişimi verilerek%s çözülebilir",
    "Sample configuration detected" : "Örnek yapılandırma tespit edildi",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Örnek yapılandırmanın kopyalanmış olabileceği tespit edildi. Bu kurulumunuzu bozabilir ve desteklenmemektedir. Lütfen config.php dosyasında değişiklik yapmadan önce belgelendirmeyi okuyun",
    "PHP %s or higher is required." : "PHP %s veya daha üst sürümü gerekli.",
    "PHP with a version lower than %s is required." : "PHP'nin %s sürümü öncesi gerekli.",
    "%sbit or higher PHP required." : "%s-bit veya daha üst PHP sürümü gerekli.",
    "Following databases are supported: %s" : "Şu veritabanları desteklenmekte: %s",
    "The command line tool %s could not be found" : "Komut satırı aracı %s bulunamadı",
    "The library %s is not available." : "%s kütüphanesi mevcut değil.",
    "Library %s with a version higher than %s is required - available version %s." : "%s kütüphanesinin %s sürümünden daha yüksek sürümü gerekli - kullanılabilir sürüm %s.",
    "Library %s with a version lower than %s is required - available version %s." : "%s kütüphanesinin %s sürümünden daha düşük sürümü gerekli - kullanılabilir sürüm %s.",
    "Following platforms are supported: %s" : "Aşağıdaki platformlar destekleniyor: %s",
    "ownCloud %s or higher is required." : "ownCloud %s veya daha üstü gerekli.",
    "ownCloud %s or lower is required." : "ownCloud %s veya daha düşük sürüm gerekli.",
    "Unknown filetype" : "Bilinmeyen dosya türü",
    "Invalid image" : "Geçersiz resim",
    "today" : "bugün",
    "yesterday" : "dün",
    "_%n day ago_::_%n days ago_" : ["%n gün önce","%n gün önce"],
    "last month" : "geçen ay",
    "_%n month ago_::_%n months ago_" : ["%n ay önce","%n ay önce"],
    "last year" : "geçen yıl",
    "_%n year ago_::_%n years ago_" : ["%n yıl önce","%n yıl önce"],
    "_%n hour ago_::_%n hours ago_" : ["%n saat önce","%n saat önce"],
    "_%n minute ago_::_%n minutes ago_" : ["%n dakika önce","%n dakika önce"],
    "seconds ago" : "saniyeler önce",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "%s kimlikli modül mevcut değil. Lütfen uygulamalar içerisinden etkinleştirin veya sistem yöneticinize danışın.",
    "Builtin" : "Yerleşik",
    "None" : "Hiçbiri",
    "Username and password" : "Kullanıcı adı ve parola",
    "Username" : "Kullanıcı adı",
    "Password" : "Parola",
    "Log-in credentials, save in session" : "Oturum kimlik bilgileri, oturumda kaydet",
    "Empty filename is not allowed" : "Boş dasya adına izin verilmiyor",
    "Dot files are not allowed" : "Nokta dosyalarına izin verilmiyor",
    "4-byte characters are not supported in file names" : "4 bayt karakterler dosya adlarında desteklenmez",
    "File name is a reserved word" : "Bu dosya adı özel bir kullanıma aittir",
    "File name contains at least one invalid character" : "Dosya adı en az bir geçersiz karakter içeriyor",
    "File name is too long" : "Dosya adı çok uzun",
    "App directory already exists" : "Uygulama dizini zaten mevcut",
    "Can't create app folder. Please fix permissions. %s" : "Uygulama dizini oluşturulamıyor. Lütfen izinleri düzeltin. %s",
    "Archive does not contain a directory named %s" : "Arşivde %s adında bir dizin bulunmuyor",
    "No source specified when installing app" : "Uygulama kurulurken bir kaynak belirtilmedi",
    "No href specified when installing app from http" : "Uygulama http'den kurulurken href belirtilmedi",
    "No path specified when installing app from local file" : "Uygulama yerel dosyadan kurulurken dosya yolu belirtilmedi",
    "Archives of type %s are not supported" : "%s arşiv türü desteklenmiyor",
    "Failed to open archive when installing app" : "Uygulama kurulurken arşiv dosyası açılamadı",
    "App does not provide an info.xml file" : "Uygulama info.xml dosyası sağlamıyor",
    "App cannot be installed because appinfo file cannot be read." : "Appinfo dosyası okunamadığından uygulama yüklenemiyor.",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "İmza denetlenemedi. Lütfen uygulama yöneticisi ile iletişime geçin ve yönetici ekranınıza bakın.",
    "App can't be installed because of not allowed code in the App" : "Uygulama, izin verilmeyen kodlar barındırdığından kurulamıyor",
    "App can't be installed because it is not compatible with this version of ownCloud" : "ownCloud sürümünüz ile uyumsuz olduğu için uygulama kurulamıyor",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Uygulama, birlikte gelmeyen uygulama olmasına rağmen <shipped>true</shipped> etiketi içerdiği için kurulamıyor",
    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "Uygulama info.xml içindeki sürüm ile uygulama marketinde belirtilen sürüm aynı olmadığından kurulamıyor",
    "Apps" : "Uygulamalar",
    "General" : "Genel",
    "Storage" : "Depolama",
    "Security" : "Güvenlik",
    "Encryption" : "Şifreleme",
    "Sharing" : "Paylaşım",
    "Search" : "Ara",
    "Updates" : "Güncellemeler",
    "%s enter the database username and name." : "%s veritabanı adı ve kullanıcı adını girin.",
    "%s enter the database username." : "%s veritabanı kullanıcı adını girin.",
    "%s enter the database name." : "%s veritabanı adını girin.",
    "%s you may not use dots in the database name" : "%s veritabanı adında nokta kullanamayabilirsiniz",
    "Oracle connection could not be established" : "Oracle bağlantısı kurulamadı",
    "Oracle username and/or password not valid" : "Oracle kullanıcı adı ve/veya parolası geçerli değil",
    "DB Error: \"%s\"" : "VT Hatası: \"%s\"",
    "Offending command was: \"%s\"" : "Saldırgan komut: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Mevcut bit hesap ya da yönetici hesabını girmelisiniz.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Hatalı komut: \"%s\", ad: %s, parola: %s",
    "PostgreSQL username and/or password not valid" : "PostgreSQL  kullanıcı adı ve/veya parolası geçerli değil",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X desteklenmiyor ve %s bu platformda düzgün çalışmayacak. Kendi riskinizle kullanın!",
    "For the best results, please consider using a GNU/Linux server instead." : "En iyi sonuçlar için GNU/Linux sunucusu kullanın.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Bu %s örneğinin 32-bit PHP ortamında çalıştırıldığı ve open_basedir ayarının php.ini içerisinde yapılandırıldığı görülüyor. Bu 4 GB üzerindeki dosyalarda sorun oluşturacaktır ve kullanılması önerilmez.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Lütfen php.ini içerisindeki open_basedir ayarını kaldırın veya 64-bit PHP'ye geçin.",
    "Set an admin username." : "Bir yönetici kullanıcı adı ayarlayın.",
    "Set an admin password." : "Bir yönetici kullanıcı parolası ayarlayın.",
    "Can't create or write into the data directory %s" : "Veri dizini %s oluşturulamıyor veya yazılamıyor",
    "Invalid Federated Cloud ID" : "Geçersiz Birleşmiş Bulut Kimliği",
    "%s shared »%s« with you" : "%s sizinle »%s« paylaşımında bulundu",
    "%s via %s" : "%s, %s aracılığıyla",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Arka uç %i türündeki paylaşımlara izin vermediğinden %s paylaşımı başarısız",
    "Sharing %s failed, because the file does not exist" : "%s paylaşımı, dosya mevcut olmadığından başarısız oldu",
    "You are not allowed to share %s" : "%s paylaşımını yapma izniniz yok",
    "Sharing %s failed, because you can not share with yourself" : "%s paylaşımı başarısız, kendiniz ile paylaşamazsınız",
    "Sharing %s failed, because the user %s does not exist" : "%s paylaşımı, %s kullanıcısı mevcut olmadığından başarısız oldu",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s paylaşımı, %s kullanıcısının %s üyeliklerinden birine sahip olmadığından başarısız oldu",
    "Sharing %s failed, because this item is already shared with %s" : "%s paylaşımı, %s ile zaten paylaşıldığından dolayı başarısız oldu",
    "Sharing %s failed, because this item is already shared with user %s" : "%s paylaşımı başarısız oldu çünkü bu öge zaten %s kullanıcısı ile paylaşılıyor",
    "Sharing %s failed, because the group %s does not exist" : "%s paylaşımı, %s grubu mevcut olmadığından başarısız oldu",
    "Sharing %s failed, because %s is not a member of the group %s" : "%s paylaşımı, %s kullanıcısı %s grup üyesi olmadığından başarısız oldu",
    "You need to provide a password to create a public link, only protected links are allowed" : "Herkese açık bir bağlantı oluşturmak için bir parola belirtmeniz gerekiyor. Sadece korunmuş bağlantılara izin verilmektedir",
    "Sharing %s failed, because sharing with links is not allowed" : "%s paylaşımı, bağlantılar ile paylaşım izin verilmediğinden başarısız oldu",
    "Not allowed to create a federated share with the same user" : "Aynı kullanıcı ile bir birleşik paylaşım oluşturulamaz",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s paylaşımı başarısız. %s bulunamadı veya sunucu şu anda ulaşılamıyor olabilir.",
    "Share type %s is not valid for %s" : "%s paylaşım türü %s için geçerli değil",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "%s için izinler, izinler %s için verilen izinleri aştığından dolayı ayarlanamadı",
    "Setting permissions for %s failed, because the item was not found" : "%s için izinler öge bulunamadığından ayarlanamadı",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Son kullanma tarihi ayarlanamıyor. Paylaşımlar, paylaşıldıkları süreden %s sonra dolamaz.",
    "Cannot set expiration date. Expiration date is in the past" : "Son kullanma tarihi ayarlanamıyor. Son kullanma tarihi geçmişte",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Son kullanım tarihi temizlenemiyor. Paylaşımların bir son kullanma tarihi olmalı.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Paylaşma arka ucu %s OCP\\Share_Backend arayüzünü desteklemeli",
    "Sharing backend %s not found" : "Paylaşım arka ucu %s bulunamadı",
    "Sharing backend for %s not found" : "%s için paylaşım arka ucu bulunamadı",
    "Sharing failed, because the user %s is the original sharer" : "%s kullanıcısı özgün paylaşan kişi olduğundan başarısız oldu",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "%s paylaşımı, izinler %s için verilen izinleri aştığından dolayı başarısız oldu",
    "Sharing %s failed, because resharing is not allowed" : "%s paylaşımı, tekrar paylaşımın izin verilmemesinden dolayı başarısız oldu",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s paylaşımı, %s için arka ucun kaynağını bulamamasından dolayı başarısız oldu",
    "Sharing %s failed, because the file could not be found in the file cache" : "%s paylaşımı, dosyanın dosya önbelleğinde bulunamamasınndan dolayı başarısız oldu",
    "Cannot increase permissions of %s" : "%s izinleri yükseltilemiyor",
    "Files can't be shared with delete permissions" : "Dosyalar silme izni ile paylaşılamaz",
    "Files can't be shared with create permissions" : "Dosyalar oluşturma izni ile paylaşılamaz",
    "Expiration date is in the past" : "Son kullanma tarihi geçmişte",
    "Cannot set expiration date more than %s days in the future" : "Paylaşımların son kullanım süreleri, gelecekte %s günden fazla olamaz",
    "Could not find category \"%s\"" : "\"%s\" kategorisi bulunamadı",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Kullanıcı adında sadece bu karakterlere izin verilmektedir: \"a-z\", \"A-Z\", \"0-9\", ve \"_.@-'\"",
    "A valid username must be provided" : "Geçerli bir kullanıcı adı mutlaka sağlanmalı",
    "Username contains whitespace at the beginning or at the end" : "Kullanıcı adı başlangıç veya sonda boşluk içeriyor",
    "A valid password must be provided" : "Geçerli bir parola mutlaka sağlanmalı",
    "The username is already being used" : "Bu kullanıcı adı zaten kullanımda",
    "Login canceled by app" : "Giriş uygulama tarafından iptal edildi",
    "User disabled" : "Kullanıcı devre dışı",
    "Help" : "Yardım",
    "Settings" : "Ayarlar",
    "Users" : "Kullanıcılar",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "\"%s\" uygulaması, şu bağımlılıklar sağlanmadığı için yüklenemiyor: %s",
    "web services under your control" : "denetiminizdeki web hizmetleri",
    "File is currently busy, please try again later" : "Dosya şu anda meşgul, lütfen daha sonra deneyin",
    "Can't read file" : "Dosya okunamıyor",
    "Application is not enabled" : "Uygulama etkin değil",
    "Authentication error" : "Kimlik doğrulama hatası",
    "Token expired. Please reload page." : "Belirteç süresi geçti. Lütfen sayfayı yenileyin.",
    "Unknown user" : "Bilinmeyen kullanıcı",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Yüklü veritabanı sürücüsü (sqlite, mysql veya postgresql) yok.",
    "Cannot write into \"config\" directory" : "\"config\" dizinine yazılamıyor",
    "Cannot write into \"apps\" directory" : "\"apps\" dizinine yazılamıyor",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Bu genellikle, %sweb sunucusuna apps dizinine yazma erişimi verilerek%s veya yapılandırma dosyasında appstore (uygulama mağazası) devre dışı bırakılarak çözülebilir.",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Bu genellikle, <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">web sunucusuna kök dizinine yazma erişimi verilerek</a> çözülebilir.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "İzinler genellikle, %sweb sunucusuna kök dizinine yazma erişimi verilerek%s çözülebilir",
    "Setting locale to %s failed" : "Dili %s olarak ayarlama başarısız",
    "Please install one of these locales on your system and restart your webserver." : "Lütfen bu yerellerden birini sisteminize yükleyin ve web sunucunuzu yeniden başlatın.",
    "Please ask your server administrator to install the module." : "Lütfen modülün kurulması için sunucu yöneticinize danışın.",
    "PHP module %s not installed." : "PHP modülü %s yüklü değil.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP ayarı \"%s\", \"%s\" olarak ayarlanmamış.",
    "Adjusting this setting in php.ini will make ownCloud run again" : "Bu ayarı php.ini içerisinde ayarlamak ownCloud'ı tekrar çalıştıracak.",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload, beklenen \"0\" değerinin aksine \"%s\" olarak ayarlanmış",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Bu hatayı düzeltmek için php.ini içerisindeki <code>mbstring.func_overload</code> ayarını <code>0</code> olarak ayarlayın",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "En düşük libxml2 2.7.0 gerekli. Şu anda %s kurulu.",
    "To fix this issue update your libxml2 version and restart your web server." : "Bu sorunu çözmek için libxml2 sürümünüzü güncelleyin ve web sunucusunu yeniden başlatın.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP satıriçi doc bloklarını ayıklamak üzere yapılandırılmış gibi görünüyor. Bu, bazı çekirdek uygulamalarını erişilemez yapacak.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Bu, muhtemelen Zend OPcache veya eAccelerator gibi bir önbellek/hızlandırıcı nedeniyle meydana gelir.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP modülleri yüklü, ancak hala eksik olarak mı görünüyorlar?",
    "Please ask your server administrator to restart the web server." : "Lütfen web sunucusunu yeniden başlatması için sunucu yöneticinize danışın.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 gerekli",
    "Please upgrade your database version" : "Lütfen veritabanı sürümünüzü yükseltin",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Lütfen izinleri 0770 olarak ayarlayıp dizinin diğer kullanıcılar tarafından görülememesini sağlayın.",
    "Check the value of \"datadirectory\" in your configuration" : "Yapılandırmanızdaki \"datadirectory\" değerini denetleyin",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Lütfen veri dizininin kökünde \".ocdata\" adlı bir dosyanın bulunduğunu denetleyin.",
    "Could not obtain lock type %d on \"%s\"." : "\"%s\" üzerinde %d kilit türü alınamadı.",
    "Storage unauthorized. %s" : "Depolamaya erişim izni yok. %s",
    "Storage incomplete configuration. %s" : "Depolamada tamamlanmamış yapılandırma. %s",
    "Storage connection error. %s" : "Depolama bağlantı hatası. %s",
    "Storage connection timeout. %s" : "Depolama bağlantı zaman aşımı. %s",
    "A safe home for all your data" : "Verileriniz için güvenli bir yuva",
    "Imprint" : "İzlenim",
    "__language_name__" : "Türkçe"
},
"nplurals=2; plural=(n > 1);");
